// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
//
// See the LICENSE.txt file for license information. Please report all
// issues on https://gitlab.onelab.info/getdp/getdp/issues.

#ifndef MOVING_BAND_2D_H
#define MOVING_BAND_2D_H

#include "ProData.h"

void Init_MovingBand2D(struct Group * Group_P);
void Mesh_MovingBand2D(struct Group * Group_P);

#endif
